@@ -1,7 +1,7 @@
 """
 Type annotations for ec2-instance-connect service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/type_defs.html)
+[Open documentation](./type_defs.md)
 
 Usage::
 
@@ -21,12 +21,20 @@ else:
 
 __all__ = ("SendSSHPublicKeyResponseTypeDef", "SendSerialConsoleSSHPublicKeyResponseTypeDef")
 
+SendSSHPublicKeyResponseTypeDef = TypedDict(
+    "SendSSHPublicKeyResponseTypeDef",
+    {
+        "RequestId": str,
+        "Success": bool,
+    },
+    total=False,
+)
 
-class SendSSHPublicKeyResponseTypeDef(TypedDict, total=False):
-    RequestId: str
-    Success: bool
-
-
-class SendSerialConsoleSSHPublicKeyResponseTypeDef(TypedDict, total=False):
-    RequestId: str
-    Success: bool
+SendSerialConsoleSSHPublicKeyResponseTypeDef = TypedDict(
+    "SendSerialConsoleSSHPublicKeyResponseTypeDef",
+    {
+        "RequestId": str,
+        "Success": bool,
+    },
+    total=False,
+)
